package com.upay.sdk.icc;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.FastJsonUtils;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import com.upay.sdk.icc.v_3.executer.CashierOrderExecuter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;


public class CashierCallbckServlet extends HttpServlet {

    final static Logger LOGGER = LoggerFactory.getLogger(CashierCallbckServlet.class);


    private static final String ENCRYPT_KEY = "encryptKey";
    private static final String MERCHANT_ID = "merchantId";
    private static final String DATA = "data";
    private static final String REQUEST_ID = "requestId";

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req,resp);
    }


    @Override
    protected void doPost(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        CashierOrderExecuter executer = new CashierOrderExecuter();
        final PrintWriter out = resp.getWriter();
        try{
            JSONObject json = new JSONObject();
            json.put(REQUEST_ID,req.getParameter(REQUEST_ID));
            json.put(DATA,req.getParameter(DATA).replace(" ", "+"));
            json.put(ENCRYPT_KEY,req.getParameter(ENCRYPT_KEY).replace(" ","+"));
            json.put(MERCHANT_ID,req.getParameter(MERCHANT_ID));
            LOGGER.info("icc-cashier-callback:[{}]", json.toJSONString());
            executer.bothCipherCallback(json, new ResultListenerAdpater() {
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.info("订单成功！");
                    LOGGER.info(jsonObject.toJSONString());
                    out.print(jsonObject.toJSONString());
                }

                @Override
                public void failure(JSONObject jsonObject) {
                    LOGGER.info("订单失败！",jsonObject);
                    LOGGER.info(jsonObject.toJSONString());
                    out.print(jsonObject.toJSONString());
                }
            });
        }
        catch(ResponseException e){
            LOGGER.info("响应异常");
            LOGGER.info(e.toString());
            out.print("响应异常");
        }
        catch(HmacVerifyException e){
            LOGGER.info("签名验证异常");
            LOGGER.info(e.toString());
            out.print("签名验证异常");
        }
        catch(Exception e){
            LOGGER.error("exception", e);
            LOGGER.info("未知异常");
            out.print("未知异常");
        }
        LOGGER.info("ICC order notify success...");
    }


}
