package com.upay.sdk.icc;

import com.alibaba.fastjson.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;


import com.upay.sdk.icc.v_3.builder.CashierOrderBuilder;
import com.upay.sdk.icc.v_3.entity.BillInfo;
import com.upay.sdk.icc.v_3.entity.ShipInfo;
import com.upay.sdk.icc.v_3.executer.CashierOrderExecuter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * 收银台下单
 * */
public class CashierOrderServlet extends HttpServlet {

    final static Logger LOGGER = LoggerFactory.getLogger(CashierOrderServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {



        String merchantId = req.getParameter("merchantId");
        String orderAmount = req.getParameter("orderAmount");
        String orderCurrency = req.getParameter("orderCurrency");
        String requestId = req.getParameter("requestId");
        String language = req.getParameter("language");
        String notifyUrl = req.getParameter("notifyUrl");
        String callbackUrl = req.getParameter("callbackUrl");
        String terminalNo = req.getParameter("terminalNo");
        String projectId = req.getParameter("projectId");
        String remark = req.getParameter("remark");

        //送货信息
        String shipStreet = req.getParameter("shipStreet");
        String shipCity = req.getParameter("shipCity");
        String shipState = req.getParameter("shipState");
        String shipPost = req.getParameter("shipPost");
        String shipCountry = req.getParameter("shipCountry");
        String shipPhone = req.getParameter("shipPhone");
        String shipEmail = req.getParameter("shipEmail");

        //账单信息
        String billStreet = req.getParameter("billStreet");
        String billCity = req.getParameter("billCity");
        String billState = req.getParameter("billState");
        String billPost = req.getParameter("billPost");
        String billCountry = req.getParameter("billCountry");
        String billPhone = req.getParameter("billPhone");
        String billEmail = req.getParameter("billEmail");

        CashierOrderBuilder builder = new CashierOrderBuilder(merchantId);
        builder.setRequestId(requestId)
                .setOrderAmount(orderAmount)
                .setOrderCurrency(orderCurrency)
                .setNotifyUrl(notifyUrl)
                .setCallbackUrl(callbackUrl)
                .setRemark(remark)
                .setLanguage(language)
                .setTerminalNo(terminalNo)
                .setProjectId(projectId);

        ShipInfo shipInfo = new ShipInfo();
        shipInfo.setShipStreet(shipStreet);
        shipInfo.setShipCity(shipCity);
        shipInfo.setShipState(shipState);
        shipInfo.setShipPost(shipPost);
        shipInfo.setShipCountry(shipCountry);
        shipInfo.setShipPhone(shipPhone);
        shipInfo.setShipEmail(shipEmail);
        builder.setShipInfo(shipInfo);

        BillInfo billInfo = new BillInfo();
        billInfo.setBillStreet(billStreet);
        billInfo.setBillCity(billCity);
        billInfo.setBillState(billState);
        billInfo.setBillPost(billPost);
        billInfo.setBillCountry(billCountry);
        billInfo.setBillPhone(billPhone);
        billInfo.setBillEmail(billEmail);
        builder.setBillInfo(billInfo);


        final PrintWriter out = resp.getWriter();
        try{
            CashierOrderExecuter executer = new CashierOrderExecuter();
            executer.bothOrder(builder, new ResultListenerAdpater() {

                @Override
                public void success(JSONObject jsonObject){
                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
                    req.getSession().setAttribute("json",jsonObject.toJSONString());
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }
                @Override
                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
                    LOGGER.debug("jsonObject:[{}]", jsonObject.toJSONString());
                    LOGGER.debug("redirectUrl:[" + redirectUrl + "]");
                    resp.sendRedirect(redirectUrl);

                }


            });
        }
        catch(ResponseException e){
            out.println("响应异常</br>");
            out.println(e.toString());
        }
        catch(HmacVerifyException e){
            out.println("签名验证异常</br>");
            out.println(e.toString());
        }
        catch(RequestException e){
            out.println("请求异常</br>");
            out.println(e.toString());
        }
        catch(UnknownException e){
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }



}
